searchData={"items":[{"type":"module","title":"BamlElixir","doc":"","ref":"BamlElixir.html"},{"type":"module","title":"BamlElixir.Client","doc":"A client for interacting with BAML functions.\nData structures and functions are generated from BAML source files.\n\n> #### `use BamlElixir.Client, path: \"priv/baml_src\"` {: .info}\n>\n> When you `use BamlElixir.Client`, it will define:\n> - A module for each function in the BAML source files with `call/2` and `stream/3` functions along with the types.\n> - A module with `defstruct/1` and `@type t/0` for each class in the BAML source file.\n> - A module with `@type t/0` for each enum in the BAML source file.\n>\n> The `path` option is optional and defaults to `\"baml_src\"`, you may want to set it to `\"priv/baml_src\"`.\n\nThis module also provides functionality to call BAML functions either sync/async.","ref":"BamlElixir.Client.html"},{"type":"function","title":"BamlElixir.Client.call/3","doc":"Calls a BAML function synchronously.","ref":"BamlElixir.Client.html#call/3"},{"type":"function","title":"Parameters - BamlElixir.Client.call/3","doc":"- `function_name`: The name of the BAML function to call\n  - `args`: A map of arguments to pass to the function\n  - `opts`: A map of options\n    - `path`: The path to the BAML source file\n    - `collectors`: A list of collectors to use\n    - `llm_client`: The name of the LLM client to use","ref":"BamlElixir.Client.html#call/3-parameters"},{"type":"function","title":"Returns - BamlElixir.Client.call/3","doc":"- `{:ok, term()}` on success, where the term is the function's return value\n  - `{:error, String.t()}` on failure, with an error message","ref":"BamlElixir.Client.html#call/3-returns"},{"type":"function","title":"Examples - BamlElixir.Client.call/3","doc":"{:ok, result} = BamlElixir.Client.call(client, \"MyFunction\", %{arg1: \"value\"})","ref":"BamlElixir.Client.html#call/3-examples"},{"type":"macro","title":"BamlElixir.Client.generate_class_types/1","doc":"","ref":"BamlElixir.Client.html#generate_class_types/1"},{"type":"macro","title":"BamlElixir.Client.generate_enum_types/1","doc":"","ref":"BamlElixir.Client.html#generate_enum_types/1"},{"type":"macro","title":"BamlElixir.Client.generate_function_modules/2","doc":"","ref":"BamlElixir.Client.html#generate_function_modules/2"},{"type":"function","title":"BamlElixir.Client.stream/4","doc":"Streams a BAML function asynchronously.","ref":"BamlElixir.Client.html#stream/4"},{"type":"function","title":"Parameters - BamlElixir.Client.stream/4","doc":"- `function_name`: The name of the BAML function to stream\n  - `args`: A map of arguments to pass to the function\n  - `callback`: A function that will be called with the result of the function\n  - `opts`: A map of options\n    - `path`: The path to the BAML source file\n    - `collectors`: A list of collectors to use\n    - `llm_client`: The name of the LLM client to use","ref":"BamlElixir.Client.html#stream/4-parameters"},{"type":"module","title":"BamlElixir.Collector","doc":"","ref":"BamlElixir.Collector.html"},{"type":"function","title":"BamlElixir.Collector.new/1","doc":"","ref":"BamlElixir.Collector.html#new/1"},{"type":"function","title":"BamlElixir.Collector.usage/1","doc":"","ref":"BamlElixir.Collector.html#usage/1"},{"type":"module","title":"BamlElixir.Native","doc":"","ref":"BamlElixir.Native.html"},{"type":"function","title":"BamlElixir.Native.call/5","doc":"","ref":"BamlElixir.Native.html#call/5"},{"type":"function","title":"BamlElixir.Native.collector_new/1","doc":"","ref":"BamlElixir.Native.html#collector_new/1"},{"type":"function","title":"BamlElixir.Native.collector_usage/1","doc":"","ref":"BamlElixir.Native.html#collector_usage/1"},{"type":"function","title":"BamlElixir.Native.parse_baml/1","doc":"","ref":"BamlElixir.Native.html#parse_baml/1"},{"type":"function","title":"BamlElixir.Native.stream/7","doc":"","ref":"BamlElixir.Native.html#stream/7"},{"type":"module","title":"ClientTest","doc":"","ref":"ClientTest.html"},{"type":"function","title":"ClientTest.test/0","doc":"","ref":"ClientTest.html#test/0"},{"type":"module","title":"ClientTest.BadResume","doc":"","ref":"ClientTest.BadResume.html"},{"type":"type","title":"ClientTest.BadResume.t/0","doc":"","ref":"ClientTest.BadResume.html#t:t/0"},{"type":"module","title":"ClientTest.ChooseTool","doc":"","ref":"ClientTest.ChooseTool.html"},{"type":"function","title":"ClientTest.ChooseTool.call/2","doc":"","ref":"ClientTest.ChooseTool.html#call/2"},{"type":"function","title":"ClientTest.ChooseTool.stream/3","doc":"","ref":"ClientTest.ChooseTool.html#stream/3"},{"type":"module","title":"ClientTest.Company","doc":"","ref":"ClientTest.Company.html"},{"type":"type","title":"ClientTest.Company.t/0","doc":"","ref":"ClientTest.Company.html#t:t/0"},{"type":"module","title":"ClientTest.CreatePersona","doc":"","ref":"ClientTest.CreatePersona.html"},{"type":"function","title":"ClientTest.CreatePersona.call/2","doc":"","ref":"ClientTest.CreatePersona.html#call/2"},{"type":"function","title":"ClientTest.CreatePersona.stream/3","doc":"","ref":"ClientTest.CreatePersona.html#stream/3"},{"type":"module","title":"ClientTest.DescribeImage","doc":"","ref":"ClientTest.DescribeImage.html"},{"type":"function","title":"ClientTest.DescribeImage.call/2","doc":"","ref":"ClientTest.DescribeImage.html#call/2"},{"type":"function","title":"ClientTest.DescribeImage.stream/3","doc":"","ref":"ClientTest.DescribeImage.html#stream/3"},{"type":"module","title":"ClientTest.EchoString","doc":"","ref":"ClientTest.EchoString.html"},{"type":"function","title":"ClientTest.EchoString.call/2","doc":"","ref":"ClientTest.EchoString.html#call/2"},{"type":"function","title":"ClientTest.EchoString.stream/3","doc":"","ref":"ClientTest.EchoString.html#stream/3"},{"type":"module","title":"ClientTest.ExtractResume","doc":"","ref":"ClientTest.ExtractResume.html"},{"type":"function","title":"ClientTest.ExtractResume.call/2","doc":"","ref":"ClientTest.ExtractResume.html#call/2"},{"type":"function","title":"ClientTest.ExtractResume.stream/3","doc":"","ref":"ClientTest.ExtractResume.html#stream/3"},{"type":"module","title":"ClientTest.GoodResume","doc":"","ref":"ClientTest.GoodResume.html"},{"type":"type","title":"ClientTest.GoodResume.t/0","doc":"","ref":"ClientTest.GoodResume.html#t:t/0"},{"type":"module","title":"ClientTest.Literals","doc":"","ref":"ClientTest.Literals.html"},{"type":"type","title":"ClientTest.Literals.t/0","doc":"","ref":"ClientTest.Literals.html#t:t/0"},{"type":"module","title":"ClientTest.Person","doc":"","ref":"ClientTest.Person.html"},{"type":"type","title":"ClientTest.Person.t/0","doc":"","ref":"ClientTest.Person.html#t:t/0"},{"type":"module","title":"ClientTest.Persona","doc":"","ref":"ClientTest.Persona.html"},{"type":"type","title":"ClientTest.Persona.t/0","doc":"","ref":"ClientTest.Persona.html#t:t/0"},{"type":"module","title":"ClientTest.Tools","doc":"","ref":"ClientTest.Tools.html"},{"type":"type","title":"ClientTest.Tools.t/0","doc":"","ref":"ClientTest.Tools.html#t:t/0"},{"type":"module","title":"ClientTest.WhichModel","doc":"","ref":"ClientTest.WhichModel.html"},{"type":"function","title":"ClientTest.WhichModel.call/2","doc":"","ref":"ClientTest.WhichModel.html#call/2"},{"type":"function","title":"ClientTest.WhichModel.stream/3","doc":"","ref":"ClientTest.WhichModel.html#stream/3"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}